From 5d98b7b69fcbba84fa69e5b5e9a019bfbcb76e8b Mon Sep 17 00:00:00 2001
From: "Yann E. MORIN" <yann.morin.1998@free.fr>
Date: Wed, 8 Mar 2017 19:18:49 +0100
Subject: [PATCH] keepalived/ip_vs: fix integer types

The correct, standard integer types are uint8_t and uint16_t, not
u_int8_t nor u_int16_t (the latter being kernel types).

glibc and uClibc may define the kernel-compatible types, but musl (which
is standards-compliant) does not.

Signed-off-by: "Yann E. MORIN" <yann.morin.1998@free.fr>
---
 keepalived/include/ip_vs.h | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/keepalived/include/ip_vs.h b/keepalived/include/ip_vs.h
index 391fd6e..07d0ae4 100644
--- a/keepalived/include/ip_vs.h
+++ b/keepalived/include/ip_vs.h
@@ -36,7 +36,7 @@ typedef struct ip_vs_stats_user ip_vs_stats_t;
 
 struct ip_vs_service_app {
 	struct ip_vs_service_user user;
-	u_int16_t		af;
+	uint16_t		af;
 	union nf_inet_addr	nf_addr;
 #ifdef _HAVE_PE_NAME_
 	char			pe_name[IP_VS_PENAME_MAXLEN];
@@ -45,7 +45,7 @@ struct ip_vs_service_app {
 
 struct ip_vs_dest_app {
 	struct ip_vs_dest_user	user;
-	u_int16_t		af;
+	uint16_t		af;
 	union nf_inet_addr	nf_addr;
 };
 
@@ -53,7 +53,7 @@ struct ip_vs_dest_app {
 struct ip_vs_service_entry_app {
 	struct ip_vs_service_entry user;
 	ip_vs_stats_t		stats;
-	u_int16_t		af;
+	uint16_t		af;
 	union nf_inet_addr	nf_addr;
 #ifdef _HAVE_PE_NAME_
 	char			pe_name[IP_VS_PENAME_MAXLEN];
@@ -64,7 +64,7 @@ struct ip_vs_service_entry_app {
 struct ip_vs_dest_entry_app {
 	struct ip_vs_dest_entry user;
 	ip_vs_stats_t		stats;
-	u_int16_t		af;
+	uint16_t		af;
 	union nf_inet_addr	nf_addr;
 
 };
@@ -84,7 +84,7 @@ struct ip_vs_get_dests_app {
 	struct ip_vs_dest_entry_app	entrytable[0];
 	} user;
 
-	u_int16_t		af;
+	uint16_t		af;
 	union nf_inet_addr	nf_addr;
 };
 
@@ -126,13 +126,13 @@ struct ip_vs_daemon_app {
 	uint16_t		sync_maxlen;
 
 	/* Multicast Port (base) */
-	u_int16_t		mcast_port;
+	uint16_t		mcast_port;
 
 	/* Multicast TTL */
-	u_int8_t		mcast_ttl;
+	uint8_t			mcast_ttl;
 
 	/* Multicast Address Family */
-	u_int16_t		mcast_af;
+	uint16_t		mcast_af;
 
 	/* Multicast Address */
 	union nf_inet_addr	mcast_group;
